local TARGET_VERSION = 202 -- "2.2.x"
local TARGET_SUBVERSION = 13 -- ".13"
if (VERSION < TARGET_VERSION) or ((VERSION == TARGET_VERSION) and (SUBVERSION < TARGET_SUBVERSION)) then
	print(string.format("Exception: SRB2 v%d.%d.%d+ is required for this addon", TARGET_VERSION / 100, TARGET_VERSION % 100, TARGET_SUBVERSION))
	return
end

local DG_VERSION = "v1.2"
if DoomGuy then
	print(string.format("Exception: Detected another DoomGuy already loaded (%s) while trying to load this DoomGuy (%s)", DoomGuy.version, DG_VERSION))
	return
end

rawset(_G, "DoomGuy", {
	version = DG_VERSION,
	config_version = 2
})

function DoomGuy.GetTableKeys(t)
	local i, ks = 1, {}
	for k, v in pairs(t) do
		ks[i] = k
		i = $ + 1
	end
	return ks
end

function DoomGuy.PrintTable(t, indent, done)
	done = $ or {}
	indent = $ or 0
	
	local keys = DoomGuy.GetTableKeys(t)
	table.sort(keys, function(a, b)
		if (type(a) == "number") and (type(b) == "number") then
			return (a < b)
		end
		return (tostring(a) < tostring(b))
	end)
	done[t] = true

	for i = 1, #keys do
		local key = keys[i]
		local value = t[key]
		local off = string.rep(" ", indent)
		if (type(value) == "table") and not done[value] then
			done[value] = true
			
			print(off .. key .. ": ")
			DoomGuy.PrintTable(value, indent + 2, done)
			done[value] = nil
		else
			print(off .. key .. " = " .. tostring(value) .. "")
		end
	end
end

print("Loading DoomGuy " .. DoomGuy.version .. "...")
dofile("Constants.lua")
dofile("Freeslots.lua")
dofile("Cvars.lua")
dofile("Fonts.lua")
dofile("Config.lua")

dofile("Definitions/Ammo.lua")
dofile("Definitions/Weapons.lua")
dofile("Definitions/Weapons/Melee.lua")
dofile("Definitions/Weapons/Pistol.lua")
dofile("Definitions/Weapons/Shotguns.lua")
dofile("Definitions/Weapons/Chaingun.lua")
dofile("Definitions/Weapons/RocketLauncher.lua")
dofile("Definitions/Weapons/PlasmaRifle.lua")
dofile("Definitions/Weapons/BFG9000.lua")

dofile("Definitions/pickups.lua")
dofile("Definitions/Pickups/Ammo/Clip.lua")
dofile("Definitions/Pickups/Ammo/Shell.lua")
dofile("Definitions/Pickups/Ammo/Rocket.lua")
dofile("Definitions/Pickups/Ammo/Cell.lua")

dofile("Definitions/Pickups/Weapon/Pistol.lua")
dofile("Definitions/Pickups/Weapon/Shotguns.lua")
dofile("Definitions/Pickups/Weapon/Chaingun.lua")
dofile("Definitions/Pickups/Weapon/RocketLauncher.lua")
dofile("Definitions/Pickups/Weapon/plasmarifle.lua")
dofile("Definitions/Pickups/Weapon/BFG9000.lua")
dofile("Definitions/Pickups/Weapon/Chainsaw.lua")

dofile("Definitions/Pickups/Powerups/Backpack.lua")
dofile("Definitions/Pickups/Powerups/HazardSuit.lua")
dofile("Definitions/Pickups/Powerups/Berserk.lua")
dofile("Definitions/Pickups/Powerups/PartialInvisibility.lua")

dofile("Definitions/Pickups/Items/Medkits.lua")
dofile("Definitions/Pickups/Items/Armors.lua")
dofile("Definitions/Pickups/Items/Spheres.lua")
dofile("Definitions/Pickups/Items/Bonuses.lua")

dofile("Mobjs/Bullet.lua")
dofile("Mobjs/Damage.lua")

dofile("Player/Definition.lua")
dofile("Player/Spawning.lua")
dofile("Player/Specials.lua")
dofile("Player/Thinkers.lua")
dofile("Player/Damage.lua")
dofile("Player/HUD.lua")
print("Loaded DoomGuy " .. DoomGuy.version)